vortex\_detection package
=====================================

.. automodule:: IMTreatment.vortex_detection
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   IMTreatment.vortex_detection.levelset_data
   IMTreatment.vortex_detection.vortex_detection

